@@ -24,7 +24,7 @@ typedef Eo Efl_Duplicate;
  */
 #define EFL_DUPLICATE_INTERFACE efl_duplicate_interface_get()
 
-EWAPI const Efl_Class *efl_duplicate_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_duplicate_interface_get(void) EINA_CONST;
 
 /**
  * @brief Creates a carbon copy of this object and returns it.
@@ -38,7 +38,7 @@ EWAPI const Efl_Class *efl_duplicate_interface_get(void);
  *
  * @ingroup Efl_Duplicate
  */
-EOAPI Efl_Duplicate *efl_duplicate(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK Efl_Duplicate *efl_duplicate(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
